==> zio-aws-macie2_2.12-7.21.15.8-sources.jar: zio/aws/macie2/model/GetAllowListResponse.scala <==
package zio.aws.macie2.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.macie2.model.primitives.{
  __stringMin1Max512PatternSS,
  __string,
  __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922,
  __timestampIso8601,
  __stringMin1Max128Pattern,
  __stringMin22Max22PatternAZ0922
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class GetAllowListResponse(
    arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = Optional.Absent,
    createdAt: Optional[__timestampIso8601] = Optional.Absent,
    criteria: Optional[zio.aws.macie2.model.AllowListCriteria] =
      Optional.Absent,
    description: Optional[__stringMin1Max512PatternSS] = Optional.Absent,
    id: Optional[__stringMin22Max22PatternAZ0922] = Optional.Absent,
    name: Optional[__stringMin1Max128Pattern] = Optional.Absent,
    status: Optional[zio.aws.macie2.model.AllowListStatus] = Optional.Absent,
    tags: Optional[Map[__string, __string]] = Optional.Absent,
    updatedAt: Optional[__timestampIso8601] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.GetAllowListResponse = {
    import GetAllowListResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.GetAllowListResponse
      .builder()
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .optionallyWith(createdAt.map(value => value: Instant))(_.createdAt)
      .optionallyWith(criteria.map(value => value.buildAwsValue()))(_.criteria)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(status.map(value => value.buildAwsValue()))(_.status)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .optionallyWith(updatedAt.map(value => value: Instant))(_.updatedAt)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.GetAllowListResponse.ReadOnly =
    zio.aws.macie2.model.GetAllowListResponse.wrap(buildAwsValue())
}
object GetAllowListResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.GetAllowListResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.GetAllowListResponse =
      zio.aws.macie2.model.GetAllowListResponse(
        arn.map(value => value),
        createdAt.map(value => value),
        criteria.map(value => value.asEditable),
        description.map(value => value),
        id.map(value => value),
        name.map(value => value),
        status.map(value => value.asEditable),
        tags.map(value => value),
        updatedAt.map(value => value)
      )
    def arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ]
    def createdAt: Optional[__timestampIso8601]
    def criteria: Optional[zio.aws.macie2.model.AllowListCriteria.ReadOnly]
    def description: Optional[__stringMin1Max512PatternSS]
    def id: Optional[__stringMin22Max22PatternAZ0922]
    def name: Optional[__stringMin1Max128Pattern]
    def status: Optional[zio.aws.macie2.model.AllowListStatus.ReadOnly]
    def tags: Optional[Map[__string, __string]]
    def updatedAt: Optional[__timestampIso8601]
    def getArn: ZIO[
      Any,
      AwsError,
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = AwsError.unwrapOptionField("arn", arn)
    def getCreatedAt: ZIO[Any, AwsError, __timestampIso8601] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getCriteria
        : ZIO[Any, AwsError, zio.aws.macie2.model.AllowListCriteria.ReadOnly] =
      AwsError.unwrapOptionField("criteria", criteria)
    def getDescription: ZIO[Any, AwsError, __stringMin1Max512PatternSS] =
      AwsError.unwrapOptionField("description", description)
    def getId: ZIO[Any, AwsError, __stringMin22Max22PatternAZ0922] =
      AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, __stringMin1Max128Pattern] =
      AwsError.unwrapOptionField("name", name)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.macie2.model.AllowListStatus.ReadOnly] =
      AwsError.unwrapOptionField("status", status)
    def getTags: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("tags", tags)
    def getUpdatedAt: ZIO[Any, AwsError, __timestampIso8601] =
      AwsError.unwrapOptionField("updatedAt", updatedAt)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.GetAllowListResponse
  ) extends zio.aws.macie2.model.GetAllowListResponse.ReadOnly {
    override val arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value =>
        value: __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
      )
    override val createdAt: Optional[__timestampIso8601] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => value: __timestampIso8601)
    override val criteria
        : Optional[zio.aws.macie2.model.AllowListCriteria.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.criteria())
        .map(value => zio.aws.macie2.model.AllowListCriteria.wrap(value))
    override val description: Optional[__stringMin1Max512PatternSS] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value => value: __stringMin1Max512PatternSS)
    override val id: Optional[__stringMin22Max22PatternAZ0922] =
      zio.aws.core.internal
        .optionalFromNullable(impl.id())
        .map(value => value: __stringMin22Max22PatternAZ0922)
    override val name: Optional[__stringMin1Max128Pattern] =
      zio.aws.core.internal
        .optionalFromNullable(impl.name())
        .map(value => value: __stringMin1Max128Pattern)
    override val status
        : Optional[zio.aws.macie2.model.AllowListStatus.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.macie2.model.AllowListStatus.wrap(value))
    override val tags: Optional[Map[__string, __string]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: __string) -> (value: __string)
          })
          .toMap
      )
    override val updatedAt: Optional[__timestampIso8601] = zio.aws.core.internal
      .optionalFromNullable(impl.updatedAt())
      .map(value => value: __timestampIso8601)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.GetAllowListResponse
  ): zio.aws.macie2.model.GetAllowListResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_3-6.20.115.1-sources.jar: zio/aws/macie2/model/GetAllowListResponse.scala <==
package zio.aws.macie2.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.macie2.model.primitives.{
  __stringMin1Max512PatternSS,
  __string,
  __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922,
  __timestampIso8601,
  __stringMin1Max128Pattern,
  __stringMin22Max22PatternAZ0922
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class GetAllowListResponse(
    arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = Optional.Absent,
    createdAt: Optional[__timestampIso8601] = Optional.Absent,
    criteria: Optional[zio.aws.macie2.model.AllowListCriteria] =
      Optional.Absent,
    description: Optional[__stringMin1Max512PatternSS] = Optional.Absent,
    id: Optional[__stringMin22Max22PatternAZ0922] = Optional.Absent,
    name: Optional[__stringMin1Max128Pattern] = Optional.Absent,
    status: Optional[zio.aws.macie2.model.AllowListStatus] = Optional.Absent,
    tags: Optional[Map[__string, __string]] = Optional.Absent,
    updatedAt: Optional[__timestampIso8601] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.GetAllowListResponse = {
    import GetAllowListResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.GetAllowListResponse
      .builder()
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .optionallyWith(createdAt.map(value => value: Instant))(_.createdAt)
      .optionallyWith(criteria.map(value => value.buildAwsValue()))(_.criteria)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(status.map(value => value.buildAwsValue()))(_.status)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .optionallyWith(updatedAt.map(value => value: Instant))(_.updatedAt)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.GetAllowListResponse.ReadOnly =
    zio.aws.macie2.model.GetAllowListResponse.wrap(buildAwsValue())
}
object GetAllowListResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.GetAllowListResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.GetAllowListResponse =
      zio.aws.macie2.model.GetAllowListResponse(
        arn.map(value => value),
        createdAt.map(value => value),
        criteria.map(value => value.asEditable),
        description.map(value => value),
        id.map(value => value),
        name.map(value => value),
        status.map(value => value.asEditable),
        tags.map(value => value),
        updatedAt.map(value => value)
      )
    def arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ]
    def createdAt: Optional[__timestampIso8601]
    def criteria: Optional[zio.aws.macie2.model.AllowListCriteria.ReadOnly]
    def description: Optional[__stringMin1Max512PatternSS]
    def id: Optional[__stringMin22Max22PatternAZ0922]
    def name: Optional[__stringMin1Max128Pattern]
    def status: Optional[zio.aws.macie2.model.AllowListStatus.ReadOnly]
    def tags: Optional[Map[__string, __string]]
    def updatedAt: Optional[__timestampIso8601]
    def getArn: ZIO[
      Any,
      AwsError,
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = AwsError.unwrapOptionField("arn", arn)
    def getCreatedAt: ZIO[Any, AwsError, __timestampIso8601] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getCriteria
        : ZIO[Any, AwsError, zio.aws.macie2.model.AllowListCriteria.ReadOnly] =
      AwsError.unwrapOptionField("criteria", criteria)
    def getDescription: ZIO[Any, AwsError, __stringMin1Max512PatternSS] =
      AwsError.unwrapOptionField("description", description)
    def getId: ZIO[Any, AwsError, __stringMin22Max22PatternAZ0922] =
      AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, __stringMin1Max128Pattern] =
      AwsError.unwrapOptionField("name", name)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.macie2.model.AllowListStatus.ReadOnly] =
      AwsError.unwrapOptionField("status", status)
    def getTags: ZIO[Any, AwsError, Map[__string, __string]] =
      AwsError.unwrapOptionField("tags", tags)
    def getUpdatedAt: ZIO[Any, AwsError, __timestampIso8601] =
      AwsError.unwrapOptionField("updatedAt", updatedAt)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.GetAllowListResponse
  ) extends zio.aws.macie2.model.GetAllowListResponse.ReadOnly {
    override val arn: Optional[
      __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value =>
        value: __stringMin71Max89PatternArnAwsAwsCnAwsUsGovMacie2AZ19920D12AllowListAZ0922
      )
    override val createdAt: Optional[__timestampIso8601] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => value: __timestampIso8601)
    override val criteria
        : Optional[zio.aws.macie2.model.AllowListCriteria.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.criteria())
        .map(value => zio.aws.macie2.model.AllowListCriteria.wrap(value))
    override val description: Optional[__stringMin1Max512PatternSS] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value => value: __stringMin1Max512PatternSS)
    override val id: Optional[__stringMin22Max22PatternAZ0922] =
      zio.aws.core.internal
        .optionalFromNullable(impl.id())
        .map(value => value: __stringMin22Max22PatternAZ0922)
    override val name: Optional[__stringMin1Max128Pattern] =
      zio.aws.core.internal
        .optionalFromNullable(impl.name())
        .map(value => value: __stringMin1Max128Pattern)
    override val status
        : Optional[zio.aws.macie2.model.AllowListStatus.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.macie2.model.AllowListStatus.wrap(value))
    override val tags: Optional[Map[__string, __string]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: __string) -> (value: __string)
          })
          .toMap
      )
    override val updatedAt: Optional[__timestampIso8601] = zio.aws.core.internal
      .optionalFromNullable(impl.updatedAt())
      .map(value => value: __timestampIso8601)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.GetAllowListResponse
  ): zio.aws.macie2.model.GetAllowListResponse.ReadOnly = new Wrapper(impl)
}
